@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -30,7 +30,7 @@
 #include "egg-debug.h"
 
 #include "gpm-common.h"
-#include "gpm-devicekit.h"
+#include "gpm-upower.h"
 #include "gpm-marshal.h"
 #include "gpm-engine.h"
 #include "gpm-stock-icons.h"
@@ -191,6 +191,10 @@ gpm_engine_get_warning (GpmEngine *engine, DkpDevice *device)
 	/* default to no engine */
 	warning_type = GPM_ENGINE_WARNING_NONE;
 
+	/* if the device in question is on ac, don't give a warning */
+	if (state == DKP_DEVICE_STATE_CHARGING)
+		goto out;
+
 	if (type == DKP_DEVICE_TYPE_MOUSE ||
 	    type == DKP_DEVICE_TYPE_KEYBOARD) {
 
@@ -218,6 +222,8 @@ gpm_engine_get_warning (GpmEngine *engine, DkpDevice *device)
 		if (state == DKP_DEVICE_STATE_DISCHARGING)
 			warning_type = GPM_ENGINE_WARNING_DISCHARGING;
 	}
+
+ out:
 	return warning_type;
 }
 
@@ -246,7 +252,7 @@ gpm_engine_get_summary (GpmEngine *engine)
 	array = engine->priv->array;
 	for (i=0;i<array->len;i++) {
 		device = g_ptr_array_index (engine->priv->array, i);
-		part = gpm_devicekit_get_object_summary (device);
+		part = gpm_upower_get_device_summary (device);
 		if (part != NULL)
 			g_string_append_printf (tooltip, "%s\n", part);
 		g_free (part);
@@ -296,15 +302,15 @@ gpm_engine_get_icon_priv (GpmEngine *engine, DkpDeviceType device_type, GpmEngin
 		if (type == device_type && is_present) {
 			if (warning != GPM_ENGINE_WARNING_NONE) {
 				if (warning_temp == warning)
-					return gpm_devicekit_get_object_icon (device);
+					return gpm_upower_get_device_icon (device);
 				continue;
 			}
 			if (use_state) {
 				if (state == DKP_DEVICE_STATE_CHARGING || state == DKP_DEVICE_STATE_DISCHARGING)
-					return gpm_devicekit_get_object_icon (device);
+					return gpm_upower_get_device_icon (device);
 				continue;
 			}
-			return gpm_devicekit_get_object_icon (device);
+			return gpm_upower_get_device_icon (device);
 		}
 	}
 	return NULL;
