@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -38,7 +38,7 @@
 
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
-#include "gpm-devicekit.h"
+#include "gpm-upower.h"
 #include "gpm-graph-widget.h"
 
 static GtkBuilder *builder = NULL;
@@ -113,7 +113,7 @@ enum {
 static void
 gpm_stats_button_help_cb (GtkWidget *widget, gboolean data)
 {
-	//gpm_gnome_help ("update-log");
+	gpm_help_display ("statistics");
 }
 
 /**
@@ -239,7 +239,6 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 
 	/* convert the y data to a EggArrayFloat array */
 	raw = egg_array_float_new (list->len);
-	convolved = egg_array_float_new (list->len);
 	for (i=0; i<list->len; i++) {
 		point = (GpmPointObj *) g_ptr_array_index (list, i);
 		egg_array_float_set (raw, i, point->y);
@@ -280,18 +279,27 @@ gpm_stats_time_to_text (gint seconds)
 {
 	gfloat value = seconds;
 
-	if (value < 0)
-		return g_strdup ("unknown");
-	if (value < 60)
-		return g_strdup_printf ("%.0f seconds", value);
+	if (value < 0) {
+		/* TRANSLATORS: this is when the stats time is not known */
+		return g_strdup (_("Unknown"));
+	}
+	if (value < 60) {
+		/* TRANSLATORS: this is a time value, usually to show on a graph */
+		return g_strdup_printf (ngettext ("%.0f second", "%.0f seconds", value), value);
+	}
 	value /= 60.0;
-	if (value < 60)
-		return g_strdup_printf ("%.1f minutes", value);
+	if (value < 60) {
+		/* TRANSLATORS: this is a time value, usually to show on a graph */
+		return g_strdup_printf (ngettext ("%.1f minute", "%.1f minutes", value), value);
+	}
 	value /= 60.0;
-	if (value < 60)
-		return g_strdup_printf ("%.1f hours", value);
+	if (value < 60) {
+		/* TRANSLATORS: this is a time value, usually to show on a graph */
+		return g_strdup_printf (ngettext ("%.1f hour", "%.1f hours", value), value);
+	}
 	value /= 24.0;
-	return g_strdup_printf ("%.1f days", value);
+	/* TRANSLATORS: this is a time value, usually to show on a graph */
+	return g_strdup_printf (ngettext ("%.1f day", "%.1f days", value), value);
 }
 
 /**
@@ -309,22 +317,14 @@ gpm_stats_bool_to_text (gboolean ret)
 static gchar *
 gpm_stats_get_printable_device_path (DkpDevice *device)
 {
-	const gchar *prefix = "/org/freedesktop/DeviceKit/Power/devices/";
 	const gchar *object_path;
 	gchar *device_path = NULL;
-	guint len;
 
 	/* get object path */
 	object_path = dkp_device_get_object_path (device);
-	if (object_path == NULL)
-		goto out;
-	if (!g_str_has_prefix (object_path, prefix))
-		goto out;
+	if (object_path != NULL)
+		device_path = g_filename_display_basename (object_path);
 
-	/* trim */
-	len = strlen (prefix);
-	device_path = g_strdup (object_path+len);
-out:
 	return device_path;
 }
 
@@ -1154,7 +1154,7 @@ gpm_stats_add_device (DkpDevice *device)
 
 	id = dkp_device_get_object_path (device);
 	text = gpm_device_type_to_localised_text (type, 1);
-	icon = gpm_devicekit_get_object_icon (device);
+	icon = gpm_upower_get_device_icon (device);
 
 	gtk_list_store_append (list_store_devices, &iter);
 	gtk_list_store_set (list_store_devices, &iter,
@@ -1219,7 +1219,7 @@ gpm_stats_device_removed_cb (DkpClient *client, DkpDevice *device, gpointer user
 
 	/* search the list and remove the object path entry */
 	ret = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store_devices), &iter);
-	do {
+	while (ret) {
 		gtk_tree_model_get (GTK_TREE_MODEL (list_store_devices), &iter, GPM_DEVICES_COLUMN_ID, &id, -1);
 		if (g_strcmp0 (id, object_path) == 0) {
 			gtk_list_store_remove (list_store_devices, &iter);
@@ -1227,7 +1227,7 @@ gpm_stats_device_removed_cb (DkpClient *client, DkpDevice *device, gpointer user
 		}
 		g_free (id);
 		ret = gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store_devices), &iter);
-	} while (ret);
+	};
 }
 
 /**
@@ -1250,7 +1250,7 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 		history_type = GPM_HISTORY_CHARGE_VALUE;
 		/* TRANSLATORS: this is the X axis on the graph */
 		axis_x = _("Time elapsed");
-		/* TRANSLATORS: this is the Y axis on the graph */
+		/* TRANSLATORS: this is the Y axis on the graph for the whole battery device */
 		axis_y = _("Cell charge");
 	} else if (g_strcmp0 (value, GPM_HISTORY_TIME_FULL_TEXT) == 0) {
 		history_type = GPM_HISTORY_TIME_FULL_VALUE;
@@ -1293,25 +1293,25 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
 	if (g_strcmp0 (value, GPM_STATS_CHARGE_DATA_TEXT) == 0) {
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Correction factor");
 	} else if (g_strcmp0 (value, GPM_STATS_CHARGE_ACCURACY_TEXT) == 0) {
 		stats_type = GPM_STATS_CHARGE_ACCURACY_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Prediction accuracy");
 	} else if (g_strcmp0 (value, GPM_STATS_DISCHARGE_DATA_TEXT) == 0) {
 		stats_type = GPM_STATS_DISCHARGE_DATA_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Correction factor");
 	} else if (g_strcmp0 (value, GPM_STATS_DISCHARGE_ACCURACY_TEXT) == 0) {
 		stats_type = GPM_STATS_DISCHARGE_ACCURACY_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Prediction accuracy");
@@ -1430,6 +1430,43 @@ gpm_stats_set_combo_simple_text (GtkWidget *combo_box)
 					NULL);
 }
 
+/**
+ * gpm_stats_highlight_device:
+ **/
+static void
+gpm_stats_highlight_device (const gchar *object_path)
+{
+	gboolean ret;
+	gchar *id = NULL;
+	gchar *path_str;
+	guint i;
+	GtkTreeIter iter;
+	GtkTreePath *path;
+	GtkWidget *widget;
+
+	/* check valid */
+	if (!g_str_has_prefix (object_path, "/"))
+		return;
+
+	/* we have to reuse the treeview data as it may be sorted */
+	ret = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store_devices), &iter);
+	for (i=0; ret; i++) {
+		gtk_tree_model_get (GTK_TREE_MODEL (list_store_devices), &iter,
+				    GPM_DEVICES_COLUMN_ID, &id,
+				    -1);
+		if (g_strcmp0 (id, object_path) == 0) {
+			path_str = g_strdup_printf ("%i", i);
+			path = gtk_tree_path_new_from_string (path_str);
+			widget = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_devices"));
+			gtk_tree_view_set_cursor_on_cell (GTK_TREE_VIEW (widget), path, NULL, NULL, FALSE);
+			g_free (path_str);
+			gtk_tree_path_free (path);
+		}
+		g_free (id);
+		ret = gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store_devices), &iter);
+	}
+}
+
 /**
  * main:
  **/
@@ -1449,9 +1486,8 @@ main (int argc, char *argv[])
 	DkpDeviceType type;
 	guint i;
 	gint page;
-	const gchar *object_path;
 	gboolean checked;
-	gchar *last_device;
+	gchar *last_device = NULL;
 	guint retval;
 	GError *error = NULL;
 
@@ -1459,6 +1495,9 @@ main (int argc, char *argv[])
 		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
 		  /* TRANSLATORS: show verbose debugging */
 		  N_("Show extra debugging information"), NULL },
+		{ "device", '\0', 0, G_OPTION_ARG_STRING, &last_device,
+		  /* TRANSLATORS: show a device by default */
+		  N_("Select this device at startup"), NULL },
 		{ NULL}
 	};
 
@@ -1505,7 +1544,7 @@ main (int argc, char *argv[])
 	/* get UI */
 	builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (builder, GPM_DATA "/gpm-statistics.ui", &error);
-	if (error != NULL) {
+	if (retval == 0) {
 		egg_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
 	}
@@ -1601,7 +1640,6 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_wakeups"));
 	gtk_tree_view_set_model (GTK_TREE_VIEW (widget),
 				 GTK_TREE_MODEL (list_store_wakeups));
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
 
 	/* add columns to the tree view */
 	gpm_stats_add_wakeups_columns (GTK_TREE_VIEW (widget));
@@ -1724,7 +1762,8 @@ main (int argc, char *argv[])
 		current_device = g_strdup (dkp_device_get_object_path (device));
 	}
 
-	last_device = gconf_client_get_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, NULL);
+	if (last_device == NULL)
+		last_device = gconf_client_get_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, NULL);
 
 	/* has capability to measure wakeups */
 	ret = dkp_wakeups_has_capability (wakeups);
@@ -1739,21 +1778,9 @@ main (int argc, char *argv[])
 	}
 
 	/* set the correct focus on the last device */
-	for (i=0; i < devices->len; i++) {
-		object_path = (const gchar *) g_ptr_array_index (devices, i);
-		if (last_device == NULL || object_path == NULL)
-			break;
-		if (g_strcmp0 (last_device, object_path) == 0) {
-			GtkTreePath *path;
-			gchar *path_str;
-			path_str = g_strdup_printf ("%i", i);
-			path = gtk_tree_path_new_from_string (path_str);
-			widget = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_devices"));
-			gtk_tree_view_set_cursor_on_cell (GTK_TREE_VIEW (widget), path, NULL, NULL, FALSE);
-			g_free (path_str);
-			gtk_tree_path_free (path);
-		}
-	}
+	if (last_device != NULL)
+		gpm_stats_highlight_device (last_device);
+
 	g_ptr_array_unref (devices);
 
 	/* set axis */
@@ -1775,5 +1802,6 @@ out:
 	g_object_unref (list_store_info);
 unique_out:
 	g_object_unref (egg_unique);
+	g_free (last_device);
 	return 0;
 }
